@@ -123,17 +123,10 @@ void DialogBase::setButtonGuiItem(QDialogButtonBox::StandardButton button, const
 }
 
 
-int DialogBase::spacingHint()
-{
-    // from KDE4 KDialog::spacingHint()
-    return (QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
-}
-
-
 int DialogBase::verticalSpacing()
 {
     int spacing = QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing);
-    if (spacing==-1) spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    if (spacing==-1) spacing = 4;
     return (spacing);
 }
 
@@ -141,7 +134,7 @@ int DialogBase::verticalSpacing()
 int DialogBase::horizontalSpacing()
 {
     int spacing = QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing);
-    if (spacing==-1) spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    if (spacing==-1) spacing = 4;
     return (spacing);
 }
 
